@@ -11,8 +11,7 @@ def get_class_name(model):
 
 def get_temp_base():
     tid = str(threading.get_ident())
-    return os.path.join(tempfile._get_default_tempdir(),
-                        'onnc-bench', tid)
+    return os.path.join(tempfile._get_default_tempdir(), 'onnc-bench', tid)
 
 
 def get_tmp_path():
@@ -20,7 +19,4 @@ def get_tmp_path():
 
     if not os.path.exists(temp_base):
         os.makedirs(temp_base, exist_ok=True)
-    return os.path.join(temp_base,
-                        next(tempfile._get_candidate_names()))
-
-
+    return os.path.join(temp_base, next(tempfile._get_candidate_names()))
