@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Dict, Union
+from typing import Dict, Union, List
 from pathlib import Path
 import os
 import json
@@ -10,6 +10,8 @@ from onnc.bench.core.deployment import Deployment
 from .builder import IBuilder
 from onnc.bench.core.common import get_tmp_path
 from . import Compilation
+from onnc.bench.core.model.model import Model
+from onnc.bench.core.dataset.dataset import Dataset
 
 
 def spinning_cursor():
@@ -25,44 +27,6 @@ class NNUXEBuilder(IBuilder):
         self._compilations: Dict[int, Compilation] = {}
         self.output_path: str = ""
 
-    def prepare_model(self, model_path, dataset_path, model_meta,
-                      dataset_meta) -> int:
-        """ Upload a model and its corresponding calibration dataset.
-            And create a compilation.
-
-        :param str model:
-            A path to a model file
-        :param str dataset:
-            A path to a model file
-        :param Dict model_meta
-            Metadata of the model
-        :param Dict dataset_meta
-            Metadata of the dataset
-        :returns:
-            internal compilation id
-        :rtype:
-            int
-        """
-
-        compilation = Compilation()
-        compilation.model_path = model_path
-        compilation.sample_path = dataset_path
-        compilation.model_meta = model_meta
-        compilation.sample_meta = dataset_meta
-
-        _internal_cid = id(model_path)
-        self._compilations[_internal_cid] = compilation
-        return _internal_cid
-
-    def calibrate(self, model_id: int, params: Dict):
-        """Update calibration parameters
-        """
-        self._compilations[model_id].calibrator_params = params
-
-    def compile(self, model_id, params: Dict):
-        """Update compilation parameters
-        """
-        self._compilations[model_id].compiler_params = params
 
     def _compile(self,
                  model_name,
@@ -88,7 +52,6 @@ class NNUXEBuilder(IBuilder):
         compilation_list = []
         params = {}
         res = {}
-
         # Upload files and create compilation
         for iternal_cid in self._compilations:
             compilation = self._compilations[iternal_cid]
@@ -113,9 +76,12 @@ class NNUXEBuilder(IBuilder):
             report = self._compile(f'model_{idx}', model_path, sample_path,
                                    params_path, output_path)
             res[f'model_{idx}'] = report
+            report.dump_json(
+                os.path.join(output_path, f'model_{idx}', "report.json"))
+
             os.remove(params_path)
 
-            logger.info(params)
+            logger.debug(params)
 
         self.output_path = output_path
 
@@ -135,8 +101,8 @@ class NNUXEBuilder(IBuilder):
                 deployment = Deployment(None)
 
             res[i] = deployment
-
-        return Deployment(None, report=res, logs=res)
+        return res
+        # return Deployment(None, report=res, logs=res)
 
     @property
     def supported_devices(self) -> Dict:
@@ -150,6 +116,14 @@ class NNUXEBuilder(IBuilder):
             'NVDLA-NV-SMALL-DEFAULT': 'NVDLA-NV-SMALL-DEFAULT',
             'NVDLA-NV-LARGE-DEFAULT': 'NVDLA-NV-LARGE-DEFAULT',
             'NVDLA-NV-FULL-DEFAULT': 'NVDLA-NV-FULL-DEFAULT',
-            "INTEL-OPENVINO-CPU-FP32": "INTEL-OPENVINO-CPU-FP32"
+            'NVIDIA-TENSORRT-FP32' : 'NVIDIA-TENSORRT-FP32',
+            'NVIDIA-TENSORRT-FP16' : 'NVIDIA-TENSORRT-FP16',
+            'NVIDIA-TENSORRT-INT8' : 'NVIDIA-TENSORRT-INT8',
+            'RELAYIR' : 'RELAYIR',
+            "INTEL-OPENVINO-CPU-FP32": "INTEL-OPENVINO-CPU-FP32",
+            "FIXED_ONNX": "FIXED_ONNX",
+            "ONNX": "ONNX",
+            "ONNC-IN2O3": "ONNC-IN2O3",
+            "GenericONNC": "GenericONNC"
         }
         return devices
