@@ -6,6 +6,7 @@ import time
 import re
 import zipfile
 import sys
+import shutil
 import json
 
 import requests
@@ -325,6 +326,13 @@ class ONNCSaaSBuilder(IBuilder):
         with zipfile.ZipFile(tmp_download, 'r') as zip_ref:
             zip_ref.extractall(output)
 
+        # WARNING: bad practice should be fixed
+        import glob
+        dest = output / "model_0"
+        os.makedirs(dest,exist_ok=True)
+        for file_or_dir in glob.glob(f'{output}/*'):
+            shutil.move(file_or_dir, dest)
+
         if bs.data["state"] == "success":
             deployment = Deployment(output)
 
