@@ -35,15 +35,6 @@ class Identifier(metaclass=IdentifierRegistry):
         pass
 
 
-def identifier_selector(dataset: Dataset) -> Identifier:
-    print(Identifier.REGISTRY)
-    for identifier in Identifier.REGISTRY:
-        if identifier.is_me(dataset):
-            return identifier
-
-    raise NotImplementedError(f"Unable to identify {dataset.src}")
-
-
 def identify(dataset: Dataset) -> Dataset:
     for identifier in Identifier.REGISTRY:
         if identifier.is_me(dataset):
@@ -73,12 +64,12 @@ class PB(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        if isinstance(dataset.src, str):
+        if isinstance(dataset.src, str) or isinstance(dataset.src, Path):
             path = Path(dataset.src)
         else:
-            path = dataset.src
+            return False
 
-        if not (isinstance(path, Path) and path.exists() and path.is_file()):
+        if not (path.exists() and path.is_file()):
             return False
 
         if str(path).lower().endswith('.pb'):
@@ -106,14 +97,13 @@ class NPY(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        if isinstance(dataset.src, str):
+        if isinstance(dataset.src, str) or isinstance(dataset.src, Path):
             path = Path(dataset.src)
         else:
-            path = dataset.src
-
-        if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
 
+        if not (path.exists() and path.is_file()):
+            return False
         if str(path).lower().endswith('.npy'):
             return True
 
@@ -132,14 +122,13 @@ class NPYDIR(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        if isinstance(dataset.src, str):
+        if isinstance(dataset.src, str) or isinstance(dataset.src, Path):
             path = Path(dataset.src)
         else:
-            path = dataset.src
-
-        if not (isinstance(path, Path) and path.exists() and path.is_dir()):
             return False
 
+        if not (path.exists() and path.is_dir()):
+            return False
         files = os.listdir(path)
         if not files:
             return False
@@ -157,13 +146,14 @@ class NPZ(Identifier):
         if dataset.format == cls.FORMAT:
             return True
 
-        if isinstance(dataset.src, str):
+        if isinstance(dataset.src, str) or isinstance(dataset.src, Path):
             path = Path(dataset.src)
         else:
-            path = dataset.src
-
-        if not (isinstance(path, Path) and path.exists() and path.is_file()):
             return False
+
+        if not (path.exists() and path.is_file()):
+            return False
+
         if str(path).lower().endswith('.npy'):
             return True
 
