@@ -40,7 +40,7 @@ class Serializer(DatasetTransformer, metaclass=SerializerRegistry):
         return self.transform(dataset)
 
 
-def serialize(dataset: Dataset, dest: Path):
+def serialize(dataset: Dataset, dest: Path) -> Dataset:
     for serializer in Serializer.REGISTRY:
         if serializer.is_me(dataset):
             return serializer().serialize(dataset, dest)
@@ -89,7 +89,7 @@ class DirSerializer(Serializer):
             dest = dest.with_suffix('.zip')
             tmp_path = Path(get_tmp_path()[:-1])
             shutil.make_archive(str(tmp_path), 'zip', dataset.src)
-            shutil.move(str(tmp_path) + '.zip', dest)
+            shutil.move(str(tmp_path) + '.zip', str(dest))
         else:
             raise Exception(
                 f'dataset source `{dataset.src}` should be a path to a dir.')
@@ -102,6 +102,7 @@ class DirSerializer(Serializer):
         m = self.transform(dataset)
         return m
 
+
 class NONE(Serializer):
 
     FORMAT = DatasetFormat.NONE
@@ -109,9 +110,10 @@ class NONE(Serializer):
     def transform(self, dataset: Dataset):
         dest = self.get_param('dest')  # type: ignore[attr-defined]
         np.save(dest, np.zeros([1, 3, 3, 3]))
-        shutil.move(dest.with_suffix('.npy'), dest)
+        shutil.move(str(dest.with_suffix('.npy')), str(dest))
         return Dataset(dest)
 
+
 class PB(FileSerializer):
 
     FORMAT = DatasetFormat.PB
@@ -137,9 +139,10 @@ class NDARRAY(Serializer):
     FORMAT = DatasetFormat.NDARRAY
 
     def transform(self, dataset: Dataset):
+        assert isinstance(dataset.src, np.ndarray)
         dest = self.get_param('dest')  # type: ignore[attr-defined]
         np.save(dest, dataset.src)
-        shutil.move(dest.with_suffix('.npy'), dest)
+        shutil.move(str(dest.with_suffix('.npy')), str(dest))
         return Dataset(dest)
 
 
@@ -149,14 +152,17 @@ class TORCH_DATASET(Serializer):
 
     def transform(self, dataset: Dataset):
         import numpy
+        from torch import Tensor
+        from torch.utils.data import Dataset as torchDataset
+        assert isinstance(dataset.src, torchDataset)
         dest = self.get_param('dest')  # type: ignore[attr-defined]
         if isinstance(dataset.src.data, numpy.ndarray):
             dataset_npy = Dataset(dataset.src.data)
-        else:
+        elif isinstance(dataset.src.data, Tensor):
             dataset_npy = Dataset(
                 dataset.src.data.numpy())  # type: ignore[union-attr]
-        
-        # Handle NHWC data
+
+        # Handle NHWC data (Guess, might fail)
         if len(dataset_npy.src.shape) == 4 and dataset_npy.src.shape[-1] <= 3:
             dataset_npy.src = dataset_npy.src.transpose((0, 3, 1, 2))
 
@@ -169,6 +175,8 @@ class TORCH_DATALOADER(Serializer):
     FORMAT = DatasetFormat.TORCH_DATALOADER
 
     def transform(self, dataset: Dataset):
+        from torch.utils.data import DataLoader
+        assert isinstance(dataset.src, DataLoader)
         dest = self.get_param('dest')  # type: ignore[attr-defined]
         dataset_torch = Dataset(dataset.src.dataset)  # type: ignore[union-attr]
         torchdataset_serializer = TORCH_DATASET()
@@ -180,10 +188,11 @@ class KERAS_DATASET(Serializer):
     FORMAT = DatasetFormat.KERAS_DATASET
 
     def transform(self, dataset: Dataset):
+        assert isinstance(dataset.src, tuple)
         dest = self.get_param('dest')  # type: ignore[attr-defined]
         # Keras dataset is a 2x2 metric of tuple
         # ds[0] is for training , ds[0][0] is x and ds[0][1] is y
-        # ds[0] is for testing  , ds[1][0] is x and ds[1][1] is y
+        # ds[1] is for testing  , ds[1][0] is x and ds[1][1] is y
         # each record is a np.ndarray object
         # hence, we use x of testing data here
         dataset_npy = Dataset(dataset.src[1][0])  #type: ignore[index]
@@ -198,9 +207,10 @@ class TFDS_PREFETCH(Serializer):
     SHUFFLE_SIZE = 1024
 
     def transform(self, dataset: Dataset):
-        LABEL_KEYS = ['label']
-
         import tensorflow_datasets as tfds  # type: ignore[import]
+        import tensorflow as tf
+        assert isinstance(dataset.src, tf.data.Dataset)
+        LABEL_KEYS = ['label']
 
         dest = self.get_param('dest')  # type: ignore[attr-defined]
         try:
