@@ -5,14 +5,13 @@ import pickle
 from .model import Model
 
 
-class ModelTransformer(ABC):
+class ModelTransformer():
 
     NAME = 'ModelTransformer'
 
     def __init__(self):
         self.params = {}
 
-    @abstractmethod
     def transform(self, model: Model) -> object:
         raise NotImplementedError("`transform` has to be implemented")
 
